@@ -1,6 +1,8 @@
 import asyncio
-from functools import update_wrapper
 from datetime import datetime
+from functools import update_wrapper
+
+import aiohttp
 
 from fpl.constants import API_URLS
 
@@ -9,17 +11,19 @@ headers = {"User-Agent": ""}
 
 async def fetch(session, url, retries=10, cooldown=1):
     retries_count = 0
-
     while True:
-        async with session.get(url, headers=headers, raise_for_status=True) as response:
-            result = await response.json()
-            return result
-        retries_count += 1
-        if retries_count > retries:
-            raise Exception(f"Could not fetch {url} after {retries} retries")
-
-        if cooldown:
-            await asyncio.sleep(cooldown)
+        try:
+            async with session.get(url, headers=headers) as response:
+                result = await response.json()
+                return result
+        except aiohttp.client_exceptions.ContentTypeError:
+            retries_count += 1
+            
+            if retries_count > retries:
+                raise Exception(f"Could not fetch {url} after {retries} retries")
+            
+            if cooldown:
+                await asyncio.sleep(cooldown)
 
 
 async def post(session, url, payload, headers):
